"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LokiJsCollection = void 0;
/* eslint-disable @typescript-eslint/require-await */
const docdb_access_abstractions_1 = require("@js-soft/docdb-access-abstractions");
class LokiJsCollection {
    collection;
    name;
    databaseType = docdb_access_abstractions_1.DatabaseType.LokiJs;
    constructor(collection) {
        this.collection = collection;
        this.name = collection.name;
    }
    async create(object) {
        if (!object)
            return;
        if (typeof object.toJSON === "function") {
            object = object.toJSON();
        }
        this.collection.insert(object);
        return object;
    }
    async read(id) {
        const results = this.collection.chain().find({ id: id }).limit(1).data();
        return results[0];
    }
    async update(oldDocument, data) {
        if (typeof data.toJSON === "function") {
            data = data.toJSON();
        }
        data.$loki = oldDocument.$loki;
        data.meta = oldDocument.meta;
        this.collection.update(data);
        return data;
    }
    async delete(query) {
        if (typeof query === "string") {
            query = { id: query };
        }
        if (typeof query.toJSON === "function") {
            query = query.toJSON();
        }
        const resultset = this.collection.chain().find(query);
        if (resultset.data().length < 1) {
            return false;
        }
        resultset.remove();
        return true;
    }
    async list() {
        return this.collection.chain().data();
    }
    async find(query, paginationOptions) {
        let cursor = this.collection.chain().find(query);
        if (paginationOptions) {
            if (paginationOptions.skip)
                cursor = cursor.offset(paginationOptions.skip);
            if (paginationOptions.limit)
                cursor = cursor.limit(paginationOptions.limit);
        }
        return cursor.data();
    }
    async findOne(query) {
        const results = this.collection.chain().find(query).limit(1).data();
        return results[0];
    }
    async count(query) {
        const count = this.collection.count(query);
        return count;
    }
    async exists(query) {
        const count = await this.count(query);
        return count > 0;
    }
}
exports.LokiJsCollection = LokiJsCollection;
//# sourceMappingURL=LokiJsCollection.js.map